vegaMC(dataset, output_file_name="output", beta=0.5, min_region_bp_size=1000, correction=FALSE, loss_threshold=-0.2, gain_threshold=0.2, baf=TRUE, loh_threshold=0.75, loh_frequency=0.8, bs=1000, pval_threshold=0.05, html=TRUE, getGenes=TRUE, mart_database="ensembl", ensembl_dataset="hsapiens_gene_ensembl")beta=0 then the resulting
segmentation will be composed of a region for each probe (all regions
will contain just a probe). In contrast, if beta is very large,
then the segmentation will contain just a region for each chromosome.TRUE) This parameter specifies if the
dataset contains BAF measurements (default TRUE. If BAF is
available, then VegaMC is able to compute LOH imbalances.loh_threshold or lower then (1-loh_threshold)
then the respective probe is considered to be homozygous.TRUE) If this value is TRUE, then
in output will be produced an html file called
output_file_name.html in which a summary of all detected regions
is reported.TRUE) If this value is TRUE,
then in output will be produced an html file called
output_file_nameGenes.html in which the list of all genes
overlapping the significant regions is reported.ensembl) BioMart database name
you want to connect to. Possible database names can be retrieved
with the function listMarts of biomaRt package.hsapiens_gene_ensembl) BioMart
dataset used to get information from Ensembl BioMart database.
In order to obtain the list of all available dataset use the command
listDatasets of biomaRt package.signature(dataset = "character")signature(dataset = "GenoSet")genoset package.
## Run VegaMC
file.copy(system.file("example/breast_Affy500K.txt", package="VegaMC"), ".")
results <- vegaMC("breast_Affy500K.txt", "results", html=FALSE,
getGenes=FALSE)
Run the code above in your browser using DataLab